@@ -1,7 +1,10 @@
 # Version of the KS_Bot_Client package
-__version__ = "1.0.0"
+__version__ = "2.2.2"
 
-from ..ks_bot_client.bot import Bot
+try:
+  from ..ks_bot_client.bot import Bot
+except:
+  from ks_bot_client.bot import Bot
 
 if __name__ == "__main__":
   bot =  Bot("codingwithcn", "Cn031705!s")
